==> applitutoriel-js-lite-5.3.0.tgz: package/src/dao/partenaire-dao.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.3.0
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */

import { Utils } from "hornet-js-utils";
import { Class } from "hornet-js-utils/src/typescript-utils";
import { Logger } from "hornet-js-utils/src/logger";
import { PartenaireMetier } from "applitutoriel-js-common/src/models/par/par-mod";
import Map from "hornet-js-bean/src/decorators/Map";
import { PartenaireDTO, PartenaireAttributes } from "src/models/par/seq-par-mod";
import { HornetSequelizeEntityAttributes,
    HornetSequelizeInstanceModel }  from "hornet-js-database/src/sequelize/hornet-sequelize-attributes";
import { HornetGenericDAO } from "hornet-js-database/src/sequelize/hornet-generic-dao";
import { inject } from "hornet-js-core/src/inject/inject";
import { ModelDAO } from "src/dao/model-dao";
import { injectable } from "hornet-js-core/src/inject/injectable";
import { HornetSequelizeModel } from "hornet-js-database/src/sequelize/hornet-sequelize-model";
import { SequelizeUtils } from "hornet-js-database/src/sequelize/sequelize-utils";

var Op = require("sequelize/lib/operators");
const logger: Logger = Utils.getLogger("applitutoriel.src.dao.partenaire-dao");

@injectable()
export class PartenaireDAO extends HornetGenericDAO<ModelDAO, HornetSequelizeInstanceModel<PartenaireAttributes>> {
    constructor(entity: string = "partenaireEntity", @inject(ModelDAO) modelDAO?: ModelDAO) {
        super(modelDAO[entity], modelDAO);
    }

    @Map(PartenaireMetier)
    selectByCriteres(client: boolean, vip: boolean, startDate, sort: {}): Promise<PartenaireMetier[]> {
        if (!sort) {
            sort = [ {
                key: "id_partenaire",
                dir: 0,
            } ];
        }
        let tri = sort[ 0 ];

        let seqTri = [ tri[ "key" ], (!tri[ "dir" ] || tri[ "dir" ] == 0) ? "ASC" : "DESC" ];
        let criteria = {
            where: {
                client: client,
                dateModif: {
                    [ Op.gte ]: startDate
                },
            },
            include: [ {
                model: this.modelDAO.villeEntity,
                as: "laVille",
            } ],
            order: [ seqTri ],
        };
        if (vip !== undefined) {
            criteria.where["vip"] = vip;
        }
        return this.entity.findAll(criteria);
    }

    @Map(PartenaireMetier)
    selectFromId(id: number): Promise<PartenaireMetier> {
        return this.entity.findOne({
            where: {
                id},
            include: [{
                model: this.modelDAO.villeEntity,
                as: "laVille",
                include: [{
                    model: this.modelDAO.paysEntity,
                    as: "lePays"}]},
            {
                model: this.modelDAO.paysEntity,
                as: "laNationalite"},
            {
                model: this.modelDAO.civiliteEntity,
                as: "laCivilite"},
            {
                model: this.modelDAO.photoEntity,
                as: "laPhoto"},
            {
                model: this.modelDAO.produitEntity,
                as: "listeProduit"}]}).then((res) => {
                    return res;
                });
    }

    @Map(PartenaireMetier)
    selectAll(id: number | number[]): Promise<PartenaireMetier[]> {
        return this.entity.findAll({
            where: {
                id},
            include: [{
                model: this.modelDAO.villeEntity,
                as: "laVille",
                include: [{
                    model: this.modelDAO.paysEntity,
                    as: "lePays"}]},
            {
                model: this.modelDAO.paysEntity,
                as: "laNationalite"},
            {
                model: this.modelDAO.civiliteEntity,
                as: "laCivilite"},
            {
                model: this.modelDAO.photoEntity,
                as: "laPhoto"}]});
    }

    selectByIdSQL(id: number | number[]) {
        const query: string = "SELECT * FROM partenaire " +
            "INNER JOIN ville on partenaire.id_ville = ville.id_ville " +
            "INNER JOIN pays as ville_pays on ville.id_pays = ville_pays.id_pays " +
            "INNER JOIN pays on partenaire.id_pays = pays.id_pays " +
            "INNER JOIN civilite on partenaire.id_civilite = civilite.id_civilite " +
            "LEFT OUTER JOIN photo on partenaire.id_photo = photo.id_photo " +
            "WHERE partenaire.id_partenaire = :identifiant";
        return SequelizeUtils.getQuery().query(query,
            {
                replacements: {
                    identifiant: id
                },
                model: this.entity,
                type: SequelizeUtils.getQuery().QueryTypes.SELECT,
            },
        );
    }

    deleteByIdIfNotVIP(id: number | number[]): Promise<number> {
        return this.entity.destroy({
            where: {
                id,
                vip: false,
            },
        });
    }

    @Map()
    updateById(id: number, @Map(PartenaireDTO) partenaire): Promise<any> {
        partenaire.dateModif = new Date();
        this.verificationFormatDonneesPartenaire(partenaire);
        return this.entity.update(partenaire, { where: { id } });
    }

    @Map()
    insert(@Map(PartenaireDTO) partenaire): Promise<any> {
        partenaire.dateCreat = new Date();
        partenaire.dateModif = new Date();
        this.verificationFormatDonneesPartenaire(partenaire);
        return this.entity.create(partenaire);
    }

    private verificationFormatDonneesPartenaire(partenaire) {
        if ((partenaire.dateNaissance) && !(partenaire.dateNaissance instanceof Date)) {
            partenaire.dateNaissance = new Date(partenaire.dateNaissance);
        }
    }
}

==> applitutoriel-js-lite-5.4.1.tgz: package/src/dao/partenaire-dao.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.4.1
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */

import { Logger } from "hornet-js-logger/src/logger";
import { PartenaireMetier } from "applitutoriel-js-common/src/models/par/par-mod";
import Map from "hornet-js-bean/src/decorators/Map";
import { PartenaireDTO, PartenaireAttributes }  from "applitutoriel-js-lite/src/models/par/seq-par-mod";
import { HornetSequelizeInstanceModel }  from "hornet-js-database/src/sequelize/hornet-sequelize-attributes";
import { HornetGenericDAO } from "hornet-js-database/src/sequelize/hornet-generic-dao";
import { inject } from "hornet-js-core/src/inject/inject";
import { ModelDAO }  from "applitutoriel-js-lite/src/dao/model-dao";
import { injectable } from "hornet-js-core/src/inject/injectable";
import { SequelizeUtils } from "hornet-js-database/src/sequelize/sequelize-utils";
import { Promise } from "hornet-js-utils/src/promise-api";
import { QueryTypes } from "sequelize";

const Op = require("sequelize/lib/operators");
const logger: Logger = Logger.getLogger("applitutoriel.src.dao.partenaire-dao");

@injectable()
export class PartenaireDAO extends HornetGenericDAO<ModelDAO, HornetSequelizeInstanceModel<PartenaireAttributes>> {
    constructor(entity: string = "partenaireEntity", @inject(ModelDAO) modelDAO?: ModelDAO) {
        super(modelDAO[entity], modelDAO);
    }

    @Map(PartenaireMetier)
    selectByCriteres(client: boolean, vip: boolean, startDate, sort: {}): Promise<PartenaireMetier[]> {
        if (!sort) {
            sort = [ {
                key: "id_partenaire",
                dir: 0,
            } ];
        }
        let tri = sort[ 0 ];

        let seqTri = [ tri[ "key" ], (!tri[ "dir" ] || tri[ "dir" ] == 0) ? "ASC" : "DESC" ];
        let criteria = {
            where: {
                client: client,
                dateModif: {
                    [ Op.gte ]: startDate
                },
            },
            include: [ {
                model: this.modelDAO.villeEntity,
                as: "laVille",
            } ],
            order: [ seqTri ],
        };
        if (vip !== undefined) {
            criteria.where["vip"] = vip;
        }
        return this.entity.findAll(criteria);
    }

    @Map(PartenaireMetier)
    selectFromId(id: number): Promise<PartenaireMetier> {
        return this.entity.findOne({
            where: {
                id},
            include: [{
                model: this.modelDAO.villeEntity,
                as: "laVille",
                include: [{
                    model: this.modelDAO.paysEntity,
                    as: "lePays"}]},
            {
                model: this.modelDAO.paysEntity,
                as: "laNationalite"},
            {
                model: this.modelDAO.civiliteEntity,
                as: "laCivilite"},
            {
                model: this.modelDAO.photoEntity,
                as: "laPhoto"},
            {
                model: this.modelDAO.produitEntity,
                as: "listeProduit"}]}).then((res) => {
                    return res;
                });
    }

    @Map(PartenaireMetier)
    selectAll(id: number | number[]): Promise<PartenaireMetier[]> {
        return this.entity.findAll({
            where: {
                id},
            include: [{
                model: this.modelDAO.villeEntity,
                as: "laVille",
                include: [{
                    model: this.modelDAO.paysEntity,
                    as: "lePays"}]},
            {
                model: this.modelDAO.paysEntity,
                as: "laNationalite"},
            {
                model: this.modelDAO.civiliteEntity,
                as: "laCivilite"},
            {
                model: this.modelDAO.photoEntity,
                as: "laPhoto"}]});
    }

    selectByIdSQL(id: number | number[]) {
        const query: string = "SELECT * FROM partenaire " +
            "INNER JOIN ville on partenaire.id_ville = ville.id_ville " +
            "INNER JOIN pays as ville_pays on ville.id_pays = ville_pays.id_pays " +
            "INNER JOIN pays on partenaire.id_pays = pays.id_pays " +
            "INNER JOIN civilite on partenaire.id_civilite = civilite.id_civilite " +
            "LEFT OUTER JOIN photo on partenaire.id_photo = photo.id_photo " +
            "WHERE partenaire.id_partenaire = :identifiant";
        return SequelizeUtils.getQuery().query(query,
            {
                replacements: {
                    identifiant: id
                },
                model: this.entity,
                type: QueryTypes.SELECT,
            },
        );
    }

    deleteByIdIfNotVIP(id: number | number[]): Promise<number> {
        return this.entity.destroy({
            where: {
                id,
                vip: false,
            },
        });
    }

    @Map()
    updateById(id: number, @Map(PartenaireDTO) partenaire): Promise<any> {
        partenaire.dateModif = new Date();
        this.verificationFormatDonneesPartenaire(partenaire);
        return this.entity.update(partenaire, { where: { id } });
    }

    @Map()
    insert(@Map(PartenaireDTO) partenaire): Promise<any> {
        partenaire.dateCreat = new Date();
        partenaire.dateModif = new Date();
        this.verificationFormatDonneesPartenaire(partenaire);
        return this.entity.create(partenaire);
    }

    private verificationFormatDonneesPartenaire(partenaire) {
        if ((partenaire.dateNaissance) && !(partenaire.dateNaissance instanceof Date)) {
            partenaire.dateNaissance = new Date(partenaire.dateNaissance);
        }
    }
}
